        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 26 <strong>control</strong><br>0,1,2,7,8,9,10,12,13,15,16,17,21,22,23,24,25,29,30,33,34,35,36,40,43,45';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>3,14,19,28,31,32,39,41,42,44,47,48,49,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 10 <br>4,5,6,11,18,20,27,37,38,46';}
       if(rr==4 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 1 <br>26';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 26 <strong>control</strong><br>0,1,2,7,8,9,10,12,13,15,16,17,21,22,23,24,25,29,30,33,34,35,36,40,43,45';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>3,14,19,28,31,32,39,41,42,44,47,48,49,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 10 <br>4,5,6,11,18,20,27,37,38,46';}
       if(rr==23 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 1 <br>26';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 26 <strong>control</strong><br>0,1,2,7,8,9,10,12,13,15,16,17,21,22,23,24,25,29,30,33,34,35,36,40,43,45';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>3,14,19,28,31,32,39,41,42,44,47,48,49,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 10 <br>4,5,6,11,18,20,27,37,38,46';}
       if(rr==25 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 1 <br>26';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 26 <strong>control</strong><br>0,1,2,7,8,9,10,12,13,15,16,17,21,22,23,24,25,29,30,33,34,35,36,40,43,45';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>3,14,19,28,31,32,39,41,42,44,47,48,49,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 10 <br>4,5,6,11,18,20,27,37,38,46';}
       if(rr==26 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 1 <br>26';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 26 <strong>control</strong><br>0,1,2,7,8,9,10,12,13,15,16,17,21,22,23,24,25,29,30,33,34,35,36,40,43,45';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>3,14,19,28,31,32,39,41,42,44,47,48,49,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 10 <br>4,5,6,11,18,20,27,37,38,46';}
       if(rr==27 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 1 <br>26';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 26 <strong>control</strong><br>0,1,2,7,8,9,10,12,13,15,16,17,21,22,23,24,25,29,30,33,34,35,36,40,43,45';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>3,14,19,28,31,32,39,41,42,44,47,48,49,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 10 <br>4,5,6,11,18,20,27,37,38,46';}
       if(rr==28 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260506 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>26</strong> miembros: 1 <br>26';}
}
